# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`dconf`](#dconf): Installs and configures dconf

### Defined types

* [`dconf::db`](#dconf--db): Create dconf db keyfiles
* [`dconf::profile`](#dconf--profile): Create dconf profiles

## Classes

### <a name="dconf"></a>`dconf`

Installs and configures dconf

#### Examples

##### Declaring the class

```puppet
include dconf
```

#### Parameters

The following parameters are available in the `dconf` class:

* [`manage_packages`](#-dconf--manage_packages)
* [`packages`](#-dconf--packages)
* [`db_base_dir`](#-dconf--db_base_dir)
* [`profile_base_dir`](#-dconf--profile_base_dir)
* [`profiles`](#-dconf--profiles)
* [`dbs`](#-dconf--dbs)

##### <a name="-dconf--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Whether to manage the dconf packages.

Default value: `true`

##### <a name="-dconf--packages"></a>`packages`

Data type: `Array`

The packages required for dconf management. Typically sourced via hiera.

Default value: `[]`

##### <a name="-dconf--db_base_dir"></a>`db_base_dir`

Data type: `Stdlib::Absolutepath`

The base directory for dconf db files

Default value: `'/etc/dconf/db'`

##### <a name="-dconf--profile_base_dir"></a>`profile_base_dir`

Data type: `Stdlib::Absolutepath`

The base directory for dconf profiles

Default value: `'/etc/dconf/profile'`

##### <a name="-dconf--profiles"></a>`profiles`

Data type: `Optional[Hash]`

Hash of dconf profiles

Default value: `undef`

##### <a name="-dconf--dbs"></a>`dbs`

Data type: `Optional[Hash]`

Hash of dconf databases, settings and locks

Default value: `undef`

## Defined types

### <a name="dconf--db"></a>`dconf::db`

Create dconf db keyfiles

#### Examples

##### Create a dconf db keyfile with given settings

```puppet
dconf::db { 'local':
  settings => {
    'system/proxy/http' => {
      'host' => "'172.16.0.1'",
      'enabled' => 'true',
    },
    'org/gnome/desktop/background' => {
      'picture-uri' => 'file:///usr/local/rupert-corp/company-wallpaper.jpeg',
    },
  },
}
```

##### Lockdown dconf settings

```puppet
dconf::db { 'local':
  settings => {
    'system/proxy/http' => {
      'host' => "'172.16.0.1'",
      'enabled' => 'true',
    },
  locks => [
    'system/proxy/http/host',
    'system/proxy/http/enabled',
  ],
```

##### Managing multiple config files for the same db

```puppet
dconf::db { 'system-proxy':
  db_dir      => '/etc/dconf/db/local.d',
  db_filename => 'system-proxy',
  settings    => {
    'system/proxy/http' => {
      'host'    => "'172.16.0.1'",
      'enabled' => 'true',
    },
  },
}
dconf::db { 'disable-microphone':
  db_dir      => '/etc/dconf/db/local.d',
  db_filename => 'disable-micrphone',
  settings    => {
    'org/gnome/desktop/privacy' => {
      'disable-microphone' => 'true',
    },
  },
}
```

#### Parameters

The following parameters are available in the `dconf::db` defined type:

* [`settings`](#-dconf--db--settings)
* [`locks`](#-dconf--db--locks)
* [`db_dir`](#-dconf--db--db_dir)
* [`db_filename`](#-dconf--db--db_filename)
* [`db_file`](#-dconf--db--db_file)
* [`locks_dir`](#-dconf--db--locks_dir)
* [`locks_filename`](#-dconf--db--locks_filename)
* [`locks_file`](#-dconf--db--locks_file)
* [`db_dir_mode`](#-dconf--db--db_dir_mode)
* [`db_file_mode`](#-dconf--db--db_file_mode)
* [`locks_dir_mode`](#-dconf--db--locks_dir_mode)
* [`locks_file_mode`](#-dconf--db--locks_file_mode)
* [`purge`](#-dconf--db--purge)
* [`ensure`](#-dconf--db--ensure)

##### <a name="-dconf--db--settings"></a>`settings`

Data type: `Optional[Hash]`

Hash of dconf settings

Default value: `undef`

##### <a name="-dconf--db--locks"></a>`locks`

Data type: `Optional[Array]`

Array of dconf settings to lock

Default value: `undef`

##### <a name="-dconf--db--db_dir"></a>`db_dir`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db directory

Default value: `"${dconf::db_base_dir}/${name}.d"`

##### <a name="-dconf--db--db_filename"></a>`db_filename`

Data type: `String`

Name of the dconf db file

Default value: `'00-default'`

##### <a name="-dconf--db--db_file"></a>`db_file`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db file

Default value: `"${db_dir}/${db_filename}"`

##### <a name="-dconf--db--locks_dir"></a>`locks_dir`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db locks directory

Default value: `"${db_dir}/locks"`

##### <a name="-dconf--db--locks_filename"></a>`locks_filename`

Data type: `String`

Name of the dconf locks file

Default value: `'00-default'`

##### <a name="-dconf--db--locks_file"></a>`locks_file`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db locks file

Default value: `"${locks_dir}/${locks_filename}"`

##### <a name="-dconf--db--db_dir_mode"></a>`db_dir_mode`

Data type: `String`

File permissions for dconf db directory

Default value: `'0755'`

##### <a name="-dconf--db--db_file_mode"></a>`db_file_mode`

Data type: `String`

File permissions for dconf db file

Default value: `'0644'`

##### <a name="-dconf--db--locks_dir_mode"></a>`locks_dir_mode`

Data type: `String`

File permissions for dconf db locks directory

Default value: `'0755'`

##### <a name="-dconf--db--locks_file_mode"></a>`locks_file_mode`

Data type: `String`

File permissions for dconf db locks file

Default value: `'0644'`

##### <a name="-dconf--db--purge"></a>`purge`

Data type: `Boolean`

Whether to purge unmanaged files (keyfiles and lock files)

Default value: `true`

##### <a name="-dconf--db--ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Whether to ensure presence or absence of the resource

Default value: `'present'`

### <a name="dconf--profile"></a>`dconf::profile`

Create dconf profiles

#### Examples

##### Creating dconf profiles

```puppet
dconf::profile { 'local':
  entries => {
    'user' => {
      'type'  => 'user',
      'order' => 10,
     },
    'local' => {
      'type'  => 'system',
      'order' => 21,
    },
    'site' => {
      'type'  => 'system',
      'order' => 21,
    },
  },
}
```

#### Parameters

The following parameters are available in the `dconf::profile` defined type:

* [`profile_file`](#-dconf--profile--profile_file)
* [`profile_file_mode`](#-dconf--profile--profile_file_mode)
* [`ensure`](#-dconf--profile--ensure)
* [`default_entry_order`](#-dconf--profile--default_entry_order)
* [`entries`](#-dconf--profile--entries)

##### <a name="-dconf--profile--profile_file"></a>`profile_file`

Data type: `Stdlib::Absolutepath`

Absolute path to dconf profile file

Default value: `"${dconf::profile_base_dir}/${name}"`

##### <a name="-dconf--profile--profile_file_mode"></a>`profile_file_mode`

Data type: `String`

File permissions for dconf profile file

Default value: `'0644'`

##### <a name="-dconf--profile--ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Whether to ensure presence or absence of the dconf profile

Default value: `'present'`

##### <a name="-dconf--profile--default_entry_order"></a>`default_entry_order`

Data type: `String`

Default order of profile entries

Default value: `'25'`

##### <a name="-dconf--profile--entries"></a>`entries`

Data type: `Optional[Hash]`

List of entries to include in the dconf profile

Default value: `undef`

